--Thanks to Nullberri, Simca, Warla, and Ro for helping out with this

-- GLOBALS: stridform, GetBreedID_Journal, GetBreedID_Battle, BPB_CalculateBreedID, BPB_RetrieveBreedName, BPB_Round, SLASH_BATTLEPETbreedID1, SLASH_BATTLEPETbreedID2, SLASH_BATTLEPETbreedID3

-- localize globals at start
local CPB = _G.C_PetBattles
local CPJ = _G.C_PetJournal
local abs = math.abs
local min = math.min

-- declare addon-wide arrays
local breedCache = {}
local speciesCache = {}
local BasePetStatsArray = {}
local BreedStatsArray = {}
local cacheTime = true

-- get information from pet journal and pass to calculation function
function GetBreedID_Journal(nPetID)
	local nbreedID = ""
	if (nPetID) then
		-- get information from pet journal
		local nHealth, nMaxHP, nPower, nSpeed, nQuality = CPJ.GetPetStats(nPetID)
		local nSpeciesID, _, nLevel = CPJ.GetPetInfoByPetID(nPetID);
		
		-- pass to calculation function and then retrieve breed name
		nbreedID = BPB_RetrieveBreedName(BPB_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, false, false), nSpeciesID)
	else
		nbreedID = "ERR-PID"
	end
	
	return nbreedID
end

-- retrieve pre-determined Breed ID from cache for pet being moused over
function GetBreedID_Battle(self)
	local nbreedID
	
	if (self) then
		-- determine index of BreedCache array. accepted values are 1-6 with 1-3 being your pets and 4-6 being enemy pets
		local offset = 0
		if (self.petOwner == 2) then offset = 3 end
		
		-- get name for cached breedID/speciesID
		nbreedID = BPB_RetrieveBreedName(breedCache[self.petIndex + offset], speciesCache[self.petIndex + offset])
	else
		nbreedID = "ERR_SLF"
	end
	
	return nbreedID
end

-- get pet stats and breed at the start of battle before values change
local function BPB_CacheAllPets()
	for iOwner = 1, 2 do
		local IndexMax = CPB.GetNumPets(iOwner)
		for iIndex = 1, IndexMax do
			local nSpeciesID = CPB.GetPetSpeciesID(iOwner, iIndex)
			local nLevel = CPB.GetLevel(iOwner, iIndex)
			local nMaxHP = CPB.GetMaxHealth(iOwner, iIndex)
			local nPower = CPB.GetPower(iOwner, iIndex)
			local nSpeed = CPB.GetSpeed(iOwner, iIndex)
			local nQuality = CPB.GetBreedQuality(iOwner, iIndex)
			local wild = false
			local flying = false
			
			-- if pet is wild, add 20% hp to get the normal stat
			if (CPB.IsWildBattle() and iOwner == 2) then wild = true end
			
			-- still have to account for flying passive apparently; can't get the stats snapshot before passive is applied
			if (CPB.GetPetType(iOwner, iIndex) == 3) then
				if (iOwner == 1) and ((CPB.GetHealth(iOwner, iIndex) / nMaxHP) > .5) then
					flying = true
				elseif (iOwner == 2) then
					flying = true
				end
			end
			
			-- determine index of Cache arrays. accepted values are 1-6 with 1-3 being your pets and 4-6 being enemy pets
			local offset = 0
			if (iOwner == 2) then offset = 3 end
			
			-- calculate breedID and store it in cache along with speciesID
			breedCache[iIndex + offset] = BPB_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, wild, flying)
			speciesCache[iIndex + offset] = nSpeciesID
		end
	end
end

-- takes in lots of information, returns Breed ID as a number (or an error), and the rarity as a number
function BPB_CalculateBreedID(nSpeciesID, nQuality, nLevel, nMaxHP, nPower, nSpeed, wild, flying)
--print(nSpeciesID..", "..nQuality..", "..nLevel..", "..nMaxHP..", "..nPower..", "..nSpeed)
	local breedID, nQL, minQuality, maxQuality
	
	-- some pets from tooltips will have quality = 0.  this means we don't know what the quality is.
	-- so, we'll just test them all.
	-- this is done by adding another loop for rarity, though the execution differs slightly between the 2 methods.
	if nQuality == 0 then
		minQuality = 1
		maxQuality = 4
	else
		minQuality = nQuality
		maxQuality = nQuality
	end
	
	-- prevent "nil" errors if species is new to the game
	if not rawget(BasePetStatsArray, nSpeciesID) then return "NEW" end
	
	-- if level is low, then use "simca method". else, use "hugh method".
	-- also use hugh method if quality is 0, as it can guess better values for quality
	if nLevel < 5 and nQuality ~= 0 then
		-- Simca Method: calculate all real breed values.
		-- Pros: high accuracy at almost all levels.
		-- Cons: cannot account for blizz rounding errors at very high levels (levels 23-25)
		
		-- create local array and fill future cells with 0 to prevent "nil" comparison errors
		local testarray = {}
		testarray[1] = 0
		testarray[2] = 0
		testarray[3] = 0
		testarray[4] = 0
		testarray[5] = 0
		testarray[6] = 0
		testarray[7] = 0
		testarray[10] = 0
		
		-- loop through all qualities
		for nQuality = minQuality, maxQuality do
			nQL = (nQuality + 9) * nLevel
			
			-- loop through all breeds
			for ibreed = 3, 12 do
				-- hp
				local hp = (BasePetStatsArray[nSpeciesID][1] + BreedStatsArray[ibreed][1]) * nQL / 10 * 5 + 100
				if (wild == true) then
					-- hp if wild
					testarray[1] = floor((BPB_Round(hp, true) / 1.2))
					testarray[4] = BPB_Round(BPB_Round(hp, true) / 1.2, true)
					testarray[7] = floor((BPB_Round(hp, false) / 1.2))
					testarray[10] = BPB_Round(BPB_Round(hp, false) / 1.2, true)
				else
					-- hp if not wild
					testarray[1] = BPB_Round(hp, true)
					testarray[4] = BPB_Round(hp, false)
				end
				
				-- power
				local power = (BasePetStatsArray[nSpeciesID][2] + BreedStatsArray[ibreed][2])* nQL / 10
				testarray[2] = BPB_Round(power, true)
				testarray[5] = BPB_Round(power, false)
				
				-- speed
				local speed = (BasePetStatsArray[nSpeciesID][3] + BreedStatsArray[ibreed][3])* nQL / 10
				if (flying == true) then
					-- if flying
					testarray[3] = BPB_Round(speed * 1.5, true)
					testarray[6] = BPB_Round(speed * 1.5, false)
				else
					-- if not flying
					testarray[3] = BPB_Round(speed, true)
					testarray[6] = BPB_Round(speed, false)
				end
				
				-- match against known stats
				if ((testarray[1] == nMaxHP) or (testarray[4] == nMaxHP) or (testarray[7] == nMaxHP) or (testarray[10] == nMaxHP)) and ((testarray[2] == nPower) or (testarray[5] == nPower)) and ((testarray[3] == nSpeed) or (testarray[6] == nSpeed)) then
					breedID = ibreed
				end
				
				-- break out if successful
				if breedID then break end
			end
		end
		
		if not breedID then breedID = "ERR-SIM" end
	else
		-- Hugh Method: calculate diffs from expected values and pick breed closest to true values.
		-- Pros: perfect accuracy with larger numbers
		-- Cons: errors appear at very low numbers when the different breeds produce the same result (levels 1-2)
		
		-- localize base species stats and upconvert to avoid floating point errors
		local ihp = BasePetStatsArray[nSpeciesID][1] * 10
		local ipower = BasePetStatsArray[nSpeciesID][2] * 10
		local ispeed = BasePetStatsArray[nSpeciesID][3] * 10
		
		-- account for wild pet hp
		local wildfactor = 1
		if wild then wildfactor = 1.2 end
		
		-- upconvert to avoid floating point errors
		local thp = nMaxHP * 100
		local tpower = nPower * 100
		local tspeed = nSpeed * 100
		
		-- account for flying pet passive
		if flying then tspeed = tspeed / 1.5 end
		
		local current, lowest
		for i = minQuality, maxQuality do
			nQL = (i + 9) * nLevel
			
			-- calculate diffs
			local diff3 = abs(((ihp + 5) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 5) * nQL) - tpower) + abs(((ispeed + 5) * nQL) - tspeed)
			local diff4 = abs(((ihp + 0) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 20) * nQL) - tpower) + abs(((ispeed + 0) * nQL) - tspeed)
			local diff5 = abs(((ihp + 0) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 0) * nQL) - tpower) + abs(((ispeed + 20) * nQL) - tspeed)
			local diff6 = abs(((ihp + 20) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 0) * nQL) - tpower) + abs(((ispeed + 0) * nQL) - tspeed)
			local diff7 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs(((ispeed + 0) * nQL) - tspeed)
			local diff8 = abs(((ihp + 0) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff9 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 0) * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff10 = abs(((ihp + 4) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 9) * nQL) - tpower) + abs(((ispeed + 4) * nQL) - tspeed)
			local diff11 = abs(((ihp + 4) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 4) * nQL) - tpower) + abs(((ispeed + 9) * nQL) - tspeed)
			local diff12 = abs(((ihp + 9) * nQL * 5 + 10000) / wildfactor - thp) + abs(((ipower + 4) * nQL) - tpower) + abs(((ispeed + 4) * nQL) - tspeed)
			
			-- calculate min diff
			local current = min(diff3, diff4, diff5, diff6, diff7, diff8, diff9, diff10, diff11, diff12)
			
			if not lowest or current < lowest then
				lowest = current
				nQuality = i
				
				-- determine breed from min diff
				if (lowest == diff3) then breedID = 3
				elseif (lowest == diff4) then breedID = 4
				elseif (lowest == diff5) then breedID = 5
				elseif (lowest == diff6) then breedID = 6
				elseif (lowest == diff7) then breedID = 7
				elseif (lowest == diff8) then breedID = 8
				elseif (lowest == diff9) then breedID = 9
				elseif (lowest == diff10) then breedID = 10
				elseif (lowest == diff11) then breedID = 11
				elseif (lowest == diff12) then breedID = 12
				else return "ERR-HGH" -- return error if breed determination fails (impossible?)
				end
			end
		end
	end
	
	-- return breed (or error)
	if breedID then
		return breedID, nQuality
	else
		return "ERR-CAL"
	end
end

-- match breedID to name, second number, double letter code (S/S), entire base+breed stats, or just base stats
function BPB_RetrieveBreedName(breedID, species)
	-- exit if no breedID found
	if not breedID then return "ERR-ELY" end -- should be impossible now
	
	-- exit if error message found
	if (string.sub(tostring(breedID), 1, 3) == "ERR") or (tostring(breedID) == "??") or (tostring(breedID) == "NEW") then return breedID end
	
	local numbreedID = tonumber(breedID)
	local result = {}
	
	-- create user preferences if they haven't been created
	if (not stridform) then
		stridform = 3
	end
	
	if (stridform == 1) then -- return single number
		return numbreedID	
	elseif (stridform == 5) and (species) then -- return entire base+breed stats
		result[4] = tostring(BasePetStatsArray[species][1] + BreedStatsArray[numbreedID][1]) .. "/" .. tostring(BasePetStatsArray[species][2] + BreedStatsArray[numbreedID][2]) .. "/" .. tostring(BasePetStatsArray[species][3] + BreedStatsArray[numbreedID][3])
		return result[4]
	elseif (stridform == 6) and (species) then -- return base stats only (nothing to do with breed, but still, we're the only ones with species stats too)
		result[5] = tostring(BasePetStatsArray[species][1]) .. "/" .. tostring(BasePetStatsArray[species][2]) .. "/" .. tostring(BasePetStatsArray[species][3])
		return result[5]
	end
	
	if (numbreedID == 3) then
		result[1] = "3/13"
		result[2] = "B/B"
		result[3] = "Balanced"
	elseif (numbreedID == 4) then
		result[1] = "4/14"
		result[2] = "P/P"
		result[3] = "Powerful"
	elseif (numbreedID == 5) then
		result[1] = "5/15"
		result[2] = "S/S"
		result[3] = "Speedy"
	elseif (numbreedID == 6) then
		result[1] = "6/16"
		result[2] = "H/H"
		result[3] = "Hulking"
	elseif (numbreedID == 7) then
		result[1] = "7/17"
		result[2] = "H/P"
		result[3] = "Brawny"
	elseif (numbreedID == 8) then
		result[1] = "8/18"
		result[2] = "P/S"
		result[3] = "Intense"
	elseif (numbreedID == 9) then
		result[1] = "9/19"
		result[2] = "H/S"
		result[3] = "Vigorous"
	elseif (numbreedID == 10) then
		result[1] = "10/20"
		result[2] = "P/B"
		result[3] = "Strong"
	elseif (numbreedID == 11) then
		result[1] = "11/21"
		result[2] = "S/B"
		result[3] = "Quick"
	elseif (numbreedID == 12) then
		result[1] = "12/22"
		result[2] = "H/B"
		result[3] = "Healthy"
	else
		result[1] = "ERR-NAM"
		result[2] = "ERR-NAM"
		result[3] = "ERR-NAM"
	end
	
	if (stridform == 2) then -- 2 = doublenumber
		return result[1]
	elseif (stridform == 3) then -- 3 = double letter
		return result[2]
	elseif (stridform == 4) then -- 4 = full name
		return result[3]
	else -- this should never happen, but single number just in case it does
		return numbreedID
	end
end

-- add breedIDs to pet frames in Pet Battles (gets hooked regardless of the state of other addons)
local function BPB_Hook_UpdateDisplay(self)
	if not self.petOwner or not self.petIndex then return end
	
	if (cacheTime == true) then BPB_CacheAllPets() end
	
	if self.Name then
		local name = CPB.GetName(self.petOwner, self.petIndex)
		if name then self.Name:SetText(name.." ("..GetBreedID_Battle(self)..")") end
	end
	
	cacheTime = false
end

-- display breed on pet journal
hooksecurefunc("HybridScrollFrame_Update", function(scrollFrame)
	if scrollFrame==PetJournalListScrollFrame then
		if not PetJournal:IsShown() then return end
		
		local buttonName,label,labelName,petID
		for i=1,#scrollFrame.buttons do
			local thisPet = scrollFrame.buttons[i]
			local petID = thisPet.petID
			if petID then
				local _, customName, _, _, _, _, _, name = CPJ.GetPetInfoByPetID(petID)

				if customName then
					thisPet.name:SetText(customName.." ("..GetBreedID_Journal(petID)..")")
					thisPet.subName:Show();
					thisPet.subName:SetText(name);
				elseif name then
					thisPet.name:SetText(name.." ("..GetBreedID_Journal(petID)..")")
					thisPet.subName:Hide();
				end
			end
		end
	end
end)

-- display breed and quality if necessary on tooltips
hooksecurefunc("FloatingBattlePet_Show", function(speciesID, level, rarity, maxHealth, power, speed, name)
	rarity = rarity + 1
	local breedNum, quality = BPB_CalculateBreedID(speciesID, rarity, level, maxHealth, power, speed, false, false)
	local breed = BPB_RetrieveBreedName(breedNum, speciesID)

	FloatingBattlePetTooltip.Name:SetText(name.." ("..breed..")");
	if rarity == 0 then
		FloatingBattlePetTooltip.Name:SetVertexColor(ITEM_QUALITY_COLORS[quality-1].r, ITEM_QUALITY_COLORS[quality-1].g, ITEM_QUALITY_COLORS[quality-1].b);
	end
end)

-- display breed and quality if necessary on AH
hooksecurefunc("BattlePetToolTip_Show", function(speciesID, level, rarity, maxHealth, power, speed, name)
	rarity = rarity + 1
	local breedNum, quality = BPB_CalculateBreedID(speciesID, rarity, level, maxHealth, power, speed, false, false)
	local breed = BPB_RetrieveBreedName(breedNum, speciesID)

	BattlePetTooltip.Name:SetText(name.." ("..breed..")");
	if rarity == 0 then
		BattlePetTooltip.Name:SetVertexColor(ITEM_QUALITY_COLORS[quality-1].r, ITEM_QUALITY_COLORS[quality-1].g, ITEM_QUALITY_COLORS[quality-1].b);
	end
end)

-- create event handling frame and register event(s)
local BPB_Events = CreateFrame("FRAME", "BPB_Events")
BPB_Events:RegisterEvent("PET_BATTLE_OVER")

-- OnEvent handler function
local function BPB_Events_OnEvent(self, event, ...)
	if (event == "PET_BATTLE_OVER") then
		cacheTime = true
	end
end

-- set our event handler function
BPB_Events:SetScript("OnEvent", BPB_Events_OnEvent)

-- hook our function into UpdateDisplay
hooksecurefunc("PetBattleUnitFrame_UpdateDisplay", BPB_Hook_UpdateDisplay)

-- create slash commands
SLASH_BATTLEPETbreedID1 = "/battlepetbreedID"
SLASH_BATTLEPETbreedID2 = "/BPBID"
SLASH_BATTLEPETbreedID3 = "/breedID"
SlashCmdList["BATTLEPETbreedID"] = function(message)
	-- lowercase message for evaluation
	local msg = string.lower(message)
	
	-- create saved variable if missing
	if (not stridform) then
		stridform = 3
	end
	
	-- compare message against possible choices
	if (msg == "1") or (msg == "onenumber") or (msg == "one number") or (msg == "1 number") or (msg == "1#") then -- set it to only show one number
		stridform = 1
		print("Now displaying Breed IDs as a single number. Add 10 to the number to get the Breed ID if it were female (we can't tell from in-game yet - bug Blizzard!).")
	elseif (msg == "2") or (msg == "twonumber") or (msg == "two numbers") or (msg == "twonumbers") or (msg == "2 numbers") or (msg == "2numbers") then -- set it to show two numbers
		stridform = 2
		print("Now displaying Breed IDs as both of their possible numbers. The first listed number is the male breed and the second listed number is the female breed equivalent.")
	elseif (msg == "3") or (msg == "twoletter") or (msg == "two letter") or (msg == "two letters") or (msg == "twoletters") then -- set it to show two letters
		stridform = 3
		print("Now displaying Breed IDs as a pair of letters. Each letter represents an aspect of their breed. For example, P/P represents Breed 4, which is the highest Power build (has a double dose of Power). This is the default option.")
	elseif (msg == "4") or (msg == "fullword") or (msg == "word") or (msg == "words") or (msg == "full names") or (msg == "full words") or (msg == "fullwords") or (msg == "fullnames") then -- set it to show full words
		stridform = 4
		print("Now displaying Breed IDs as a full word. Note that these names are tentative for the different Breeds and not official in any way.")
	elseif (msg == "5") or (msg == "allstats") or (msg == "all stats") or (msg == "breed and base stats") or (msg == "breedbasestats") or (msg == "breedandbasestats") then
		stridform = 5
		print("Now displaying Breed ID values combined with Base Species values. This allows you to see the stats of the pet as if it were a level 1 Poor. This allows for easy comparisons between pets of different levels and rarities, so you know what they could be like relative to each other if they were level 25 and Rare.")
	elseif (msg == "6") or (msg == "basestatsonly") or (msg == "base stats only") or (msg == "base stats") or (msg == "basestats") or (msg == "speciesstats") then
		stridform = 6
		print("Now not displaying Breed IDs. Instead, displaying Base Stats for each Species. This will allow you to see the stats of the pet as if it were a level 1 Poor with no breed. This is a useful mode for making comparisons between two different species of pet.")
	elseif (msg == "h") or (msg == "help") or (msg == "?") then -- help
		print("Available commands are 'onenumber', 'twonumber', 'twoletter' (this is the default setting), 'fullword', 'allstats', 'basestatsonly', and 'help'. Example: /breedID onenumber")
	else
		print("Invalid command! Available commands are 'onenumber', 'twonumbers', 'twoletters' (this is the default setting), 'fullword', 'allstats', 'basestatsonly', and 'help'. Example: /breedID onenumber")
	end
end

-- custom rounding function to round up from 0.5 or down from 0.5 based on second argument (this is to account for a Blizzard bug)
function BPB_Round(number, roundup)
	if not number then return end
	number = tostring(number)
	if not roundup then local roundup = true end
	
	if not string.find(number, "%.") then return tonumber(number) end
	
	local period = string.find(number, "%.")
	local decimal = tonumber(string.sub(number, period + 1, period + 1))
	local newnum = tonumber(string.sub(number, 1, period - 1))
	
	if (decimal == 5) then
			if (roundup == true) then
				newnum = newnum + 1
			end
	elseif (decimal > 5) then
		newnum = newnum + 1
	end		
	return newnum
end


-- fill breed array
BreedStatsArray[3] = {0.5, 0.5, 0.5}
BreedStatsArray[4] = {0, 2, 0}
BreedStatsArray[5] = {0, 0, 2}
BreedStatsArray[6] = {2, 0, 0}
BreedStatsArray[7] = {0.9, 0.9, 0}
BreedStatsArray[8] = {0, 0.9, 0.9}
BreedStatsArray[9] = {0.9, 0, 0.9}
BreedStatsArray[10] = {0.4, 0.9, 0.4}
BreedStatsArray[11] = {0.4, 0.4, 0.9}
BreedStatsArray[12] = {0.9, 0.4, 0.4}

-- fill base stats array
BasePetStatsArray[39] = {8.5, 7.5, 8}
BasePetStatsArray[40] = {7, 8.5, 8.5}
BasePetStatsArray[41] = {7, 8.5, 8.5}
BasePetStatsArray[42] = {6.5, 9, 8.5}
BasePetStatsArray[43] = {7, 9, 8}
BasePetStatsArray[44] = {7, 8.5, 8.5}
BasePetStatsArray[45] = {7, 8.5, 8.5}
BasePetStatsArray[46] = {7.5, 7.5, 9}
BasePetStatsArray[47] = {8, 7.5, 8.5}
BasePetStatsArray[49] = {9, 7, 8}
BasePetStatsArray[50] = {9, 8, 7}
BasePetStatsArray[51] = {8.5, 8, 7.5}
BasePetStatsArray[52] = {8, 8, 8}
BasePetStatsArray[55] = {8.5, 7, 8.5}
BasePetStatsArray[56] = {8.5, 9, 6.5}
BasePetStatsArray[57] = {8.5, 7.5, 8}
BasePetStatsArray[58] = {7, 9, 8}
BasePetStatsArray[59] = {8.5, 8, 7.5}
BasePetStatsArray[64] = {8.5, 7.5, 8}
BasePetStatsArray[65] = {8.5, 7.5, 8}
BasePetStatsArray[67] = {8, 8, 8}
BasePetStatsArray[68] = {8, 8, 8}
BasePetStatsArray[69] = {7.5, 7.5, 9}
BasePetStatsArray[70] = {8, 7.5, 8.5}
BasePetStatsArray[71] = {8, 8, 8}
BasePetStatsArray[72] = {8, 7, 9}
BasePetStatsArray[73] = {8, 8, 8}
BasePetStatsArray[74] = {7.5, 7.5, 9}
BasePetStatsArray[75] = {7.5, 8.5, 8}
BasePetStatsArray[77] = {8, 8, 8}
BasePetStatsArray[78] = {7.5, 8.5, 8}
BasePetStatsArray[83] = {8.5, 7.5, 8}
BasePetStatsArray[84] = {8, 8, 8}
BasePetStatsArray[85] = {8.5, 7.5, 8}
BasePetStatsArray[86] = {8.5, 7.5, 8}
BasePetStatsArray[87] = {8, 8.5, 7.5}
BasePetStatsArray[89] = {8, 8, 8}
BasePetStatsArray[90] = {7, 8.5, 8.5}
BasePetStatsArray[92] = {8, 8, 8}
BasePetStatsArray[93] = {6.5, 9, 8.5}
BasePetStatsArray[94] = {7, 7, 10}
BasePetStatsArray[95] = {8, 8, 8}
BasePetStatsArray[106] = {8.5, 7.5, 8}
BasePetStatsArray[107] = {8, 8, 8}
BasePetStatsArray[111] = {8, 8, 8}
BasePetStatsArray[114] = {8.5, 8.5, 7}
BasePetStatsArray[115] = {8, 8, 8}
BasePetStatsArray[116] = {8, 8, 8}
BasePetStatsArray[117] = {8, 8, 8}
BasePetStatsArray[118] = {8, 8, 8}
BasePetStatsArray[119] = {8, 8, 8}
BasePetStatsArray[120] = {8, 8, 8}
BasePetStatsArray[121] = {8, 8, 8}
BasePetStatsArray[122] = {8, 8, 8}
BasePetStatsArray[124] = {8, 8, 8}
BasePetStatsArray[125] = {8, 8, 8}
BasePetStatsArray[126] = {8, 8, 8}
BasePetStatsArray[127] = {8, 7.5, 8.5}
BasePetStatsArray[128] = {8, 8, 8}
BasePetStatsArray[130] = {8, 8, 8}
BasePetStatsArray[131] = {8, 7.5, 8.5}
BasePetStatsArray[132] = {9, 8, 7}
BasePetStatsArray[136] = {8, 8, 8}
BasePetStatsArray[137] = {8, 7, 9}
BasePetStatsArray[138] = {8.5, 7.5, 8}
BasePetStatsArray[139] = {7.5, 8.5, 8}
BasePetStatsArray[140] = {8, 8.5, 7.5}
BasePetStatsArray[141] = {7.5, 7.5, 9}
BasePetStatsArray[142] = {8, 8.5, 7.5}
BasePetStatsArray[143] = {7.5, 8.5, 8}
BasePetStatsArray[144] = {7.5, 7.5, 9}
BasePetStatsArray[145] = {8.5, 7.5, 8}
BasePetStatsArray[146] = {7.5, 8, 8.5}
BasePetStatsArray[149] = {7.5, 7, 9.5}
BasePetStatsArray[153] = {8, 8, 8}
BasePetStatsArray[155] = {8, 8, 8}
BasePetStatsArray[156] = {8, 8, 8}
BasePetStatsArray[157] = {8, 8, 8}
BasePetStatsArray[158] = {8, 8, 8}
BasePetStatsArray[159] = {8, 8, 8}
BasePetStatsArray[160] = {8, 8, 8}
BasePetStatsArray[162] = {8, 8.5, 7.5}
BasePetStatsArray[163] = {8, 8.5, 7.5}
BasePetStatsArray[164] = {8, 8.5, 7.5}
BasePetStatsArray[165] = {8.5, 7.5, 8}
BasePetStatsArray[166] = {8.5, 8.5, 7}
BasePetStatsArray[167] = {9, 7.5, 7.5}
BasePetStatsArray[168] = {8.5, 7.5, 8}
BasePetStatsArray[169] = {8, 8, 8}
BasePetStatsArray[170] = {8, 8, 8}
BasePetStatsArray[171] = {8, 8, 8}
BasePetStatsArray[172] = {7.5, 8.5, 8}
BasePetStatsArray[173] = {8, 8.5, 7.5}
BasePetStatsArray[174] = {8, 8.5, 7.5}
BasePetStatsArray[175] = {7.5, 8.5, 8}
BasePetStatsArray[179] = {8.5, 8, 7.5}
BasePetStatsArray[180] = {8.5, 8, 7.5}
BasePetStatsArray[183] = {8, 8, 8}
BasePetStatsArray[186] = {7.5, 8.5, 8}
BasePetStatsArray[187] = {8.5, 8.5, 7}
BasePetStatsArray[188] = {8.5, 8.5, 7}
BasePetStatsArray[189] = {8, 8, 8}
BasePetStatsArray[190] = {8.5, 8.5, 7}
BasePetStatsArray[191] = {8.5, 7.5, 8}
BasePetStatsArray[192] = {8, 8, 8}
BasePetStatsArray[193] = {8, 8.5, 7.5}
BasePetStatsArray[194] = {8, 8, 8}
BasePetStatsArray[195] = {7.5, 7.5, 9}
BasePetStatsArray[196] = {8.5, 8, 7.5}
BasePetStatsArray[197] = {7.5, 8, 8.5}
BasePetStatsArray[198] = {8, 8, 8}
BasePetStatsArray[199] = {8, 8, 8}
BasePetStatsArray[200] = {8, 7, 9}
BasePetStatsArray[201] = {8, 8, 8}
BasePetStatsArray[202] = {8, 8, 8}
BasePetStatsArray[203] = {8, 7, 9}
BasePetStatsArray[204] = {8, 8, 8}
BasePetStatsArray[205] = {8, 8, 8}
BasePetStatsArray[206] = {8.5, 8.5, 7}
BasePetStatsArray[207] = {8, 8, 8}
BasePetStatsArray[209] = {8, 8, 8}
BasePetStatsArray[210] = {8, 8, 8}
BasePetStatsArray[211] = {8.5, 8, 7.5}
BasePetStatsArray[212] = {8, 8, 8}
BasePetStatsArray[213] = {8, 8, 8}
BasePetStatsArray[214] = {8, 8, 8}
BasePetStatsArray[215] = {8.5, 7.5, 8}
BasePetStatsArray[216] = {8, 8, 8}
BasePetStatsArray[217] = {8, 8, 8}
BasePetStatsArray[218] = {8.5, 7.5, 8}
BasePetStatsArray[220] = {8, 8, 8}
BasePetStatsArray[224] = {7, 8.5, 8.5}
BasePetStatsArray[225] = {8, 8, 8}
BasePetStatsArray[226] = {8, 8, 8}
BasePetStatsArray[227] = {8, 8, 8}
BasePetStatsArray[228] = {8, 8, 8}
BasePetStatsArray[229] = {8, 8, 8}
BasePetStatsArray[231] = {8.5, 8, 7.5}
BasePetStatsArray[232] = {7, 8.5, 8.5}
BasePetStatsArray[233] = {7, 8.5, 8.5}
BasePetStatsArray[234] = {7, 8.5, 8.5}
BasePetStatsArray[235] = {7, 8.5, 8.5}
BasePetStatsArray[236] = {7.5, 8.5, 8}
BasePetStatsArray[237] = {7, 8.5, 8.5}
BasePetStatsArray[238] = {7, 8.5, 8.5}
BasePetStatsArray[239] = {8, 8, 8}
BasePetStatsArray[240] = {8.5, 8.5, 7}
BasePetStatsArray[241] = {8, 8, 8}
BasePetStatsArray[242] = {7.5, 8.5, 8}
BasePetStatsArray[243] = {9, 9, 6}
BasePetStatsArray[244] = {8.5, 9, 6.5}
BasePetStatsArray[245] = {8, 8, 8}
BasePetStatsArray[246] = {8, 8, 8}
BasePetStatsArray[247] = {8, 8, 8}
BasePetStatsArray[248] = {8, 8, 8}
BasePetStatsArray[249] = {8.5, 8.5, 7}
BasePetStatsArray[250] = {7.5, 9, 7.5}
BasePetStatsArray[251] = {8.5, 8.5, 7}
BasePetStatsArray[253] = {8, 8, 8}
BasePetStatsArray[254] = {8, 8, 8}
BasePetStatsArray[255] = {7.5, 9, 7.5}
BasePetStatsArray[256] = {8, 9, 7}
BasePetStatsArray[257] = {8, 8, 8}
BasePetStatsArray[258] = {8.5, 9, 6.5}
BasePetStatsArray[259] = {8.5, 7.5, 8}
BasePetStatsArray[260] = {8, 8.5, 7.5}
BasePetStatsArray[261] = {8.5, 7.5, 8}
BasePetStatsArray[262] = {8.5, 7.5, 8}
BasePetStatsArray[264] = {8.5, 8.5, 7}
BasePetStatsArray[265] = {9.5, 8, 6.5}
BasePetStatsArray[266] = {8.5, 8.5, 7}
BasePetStatsArray[267] = {8, 8, 8}
BasePetStatsArray[268] = {8.5, 9, 6.5}
BasePetStatsArray[270] = {8.5, 8.5, 7}
BasePetStatsArray[271] = {8, 7.5, 8.5}
BasePetStatsArray[272] = {9, 7.5, 7.5}
BasePetStatsArray[277] = {8.5, 7.5, 8}
BasePetStatsArray[278] = {8, 8, 8}
BasePetStatsArray[279] = {8, 8, 8}
BasePetStatsArray[280] = {8, 8, 8}
BasePetStatsArray[281] = {8, 8, 8}
BasePetStatsArray[282] = {8, 8, 8}
BasePetStatsArray[283] = {8, 8, 8}
BasePetStatsArray[285] = {8, 9, 7}
BasePetStatsArray[286] = {9, 8, 7}
BasePetStatsArray[287] = {8, 7.5, 8.5}
BasePetStatsArray[289] = {9.5, 8.5, 6}
BasePetStatsArray[291] = {9, 7.5, 7.5}
BasePetStatsArray[292] = {8, 8, 8}
BasePetStatsArray[293] = {8, 8, 8}
BasePetStatsArray[294] = {8, 8, 8}
BasePetStatsArray[296] = {8, 8, 8}
BasePetStatsArray[297] = {8, 9.5, 6.5}
BasePetStatsArray[298] = {8, 8, 8}
BasePetStatsArray[301] = {7, 8.5, 8.5}
BasePetStatsArray[302] = {8.5, 8.5, 7}
BasePetStatsArray[303] = {7, 8.5, 8.5}
BasePetStatsArray[306] = {7, 8.5, 8.5}
BasePetStatsArray[307] = {8, 8, 8}
BasePetStatsArray[308] = {8, 8, 8}
BasePetStatsArray[309] = {6.5, 9, 8.5}
BasePetStatsArray[310] = {8, 8, 8}
BasePetStatsArray[311] = {8.5, 8, 7.5}
BasePetStatsArray[316] = {8.5, 7.5, 8}
BasePetStatsArray[317] = {8.5, 8.5, 7}
BasePetStatsArray[318] = {7.5, 8.5, 8}
BasePetStatsArray[319] = {6.5, 9, 8.5}
BasePetStatsArray[320] = {8.5, 7.5, 8}
BasePetStatsArray[321] = {8, 8, 8}
BasePetStatsArray[323] = {8, 8, 8}
BasePetStatsArray[325] = {7.5, 9, 7.5}
BasePetStatsArray[328] = {8, 8, 8}
BasePetStatsArray[329] = {8, 8, 8}
BasePetStatsArray[330] = {8, 8, 8}
BasePetStatsArray[331] = {8, 8, 8}
BasePetStatsArray[332] = {8, 8, 8}
BasePetStatsArray[333] = {8, 8, 8}
BasePetStatsArray[335] = {9, 7.5, 7.5}
BasePetStatsArray[336] = {8, 8, 8}
BasePetStatsArray[337] = {8, 8, 8}
BasePetStatsArray[338] = {8.5, 7.5, 8}
BasePetStatsArray[339] = {8, 8, 8}
BasePetStatsArray[340] = {8, 8, 8}
BasePetStatsArray[341] = {8, 8, 8}
BasePetStatsArray[342] = {8, 8, 8}
BasePetStatsArray[343] = {7, 8.5, 8.5}
BasePetStatsArray[344] = {8.5, 8, 7.5}
BasePetStatsArray[345] = {8, 8.5, 7.5}
BasePetStatsArray[346] = {8, 8, 8}
BasePetStatsArray[347] = {8, 8.75, 7.25}
BasePetStatsArray[348] = {8.5, 8.5, 7}
BasePetStatsArray[354] = {8, 8, 8}
BasePetStatsArray[374] = {8, 8, 8}
BasePetStatsArray[375] = {8, 8, 8}
BasePetStatsArray[378] = {8, 7, 9}
BasePetStatsArray[379] = {8, 7.5, 8.5}
BasePetStatsArray[380] = {8, 8, 8}
BasePetStatsArray[381] = {8, 8, 8}
BasePetStatsArray[382] = {8, 8, 8}
BasePetStatsArray[383] = {8, 7.5, 8.5}
BasePetStatsArray[384] = {8, 8, 8}
BasePetStatsArray[385] = {8, 7.5, 8.5}
BasePetStatsArray[386] = {8, 7.5, 8.5}
BasePetStatsArray[387] = {7.5, 8, 8.5}
BasePetStatsArray[388] = {8.5, 8, 7.5}
BasePetStatsArray[389] = {8.5, 7.5, 8}
BasePetStatsArray[390] = {8, 7.5, 8.5}
BasePetStatsArray[391] = {8, 7, 9}
BasePetStatsArray[392] = {8, 7.5, 8.5}
BasePetStatsArray[393] = {8.5, 7, 8.5}
BasePetStatsArray[394] = {8, 8, 8}
BasePetStatsArray[395] = {8.5, 8, 7.5}
BasePetStatsArray[396] = {7, 8.5, 8.5}
BasePetStatsArray[397] = {8, 8, 8}
BasePetStatsArray[398] = {8, 7.5, 8.5}
BasePetStatsArray[399] = {7.5, 8, 8.5}
BasePetStatsArray[400] = {7, 8.5, 8.5}
BasePetStatsArray[401] = {8.5, 8, 7.5}
BasePetStatsArray[402] = {8.5, 8, 7.5}
BasePetStatsArray[403] = {7.5, 8, 8.5}
BasePetStatsArray[404] = {8, 7.5, 8.5}
BasePetStatsArray[405] = {7.5, 8, 8.5}
BasePetStatsArray[406] = {8.5, 7.5, 8}
BasePetStatsArray[407] = {7, 8.5, 8.5}
BasePetStatsArray[408] = {7.5, 8, 8.5}
BasePetStatsArray[409] = {7, 8, 9}
BasePetStatsArray[410] = {8, 7.5, 8.5}
BasePetStatsArray[411] = {8, 8, 8}
BasePetStatsArray[412] = {7, 8.5, 8.5}
BasePetStatsArray[414] = {8, 8, 8}
BasePetStatsArray[415] = {7.5, 8.5, 8}
BasePetStatsArray[416] = {8, 8, 8}
BasePetStatsArray[417] = {8, 7.5, 8.5}
BasePetStatsArray[418] = {7.5, 8, 8.5}
BasePetStatsArray[419] = {8.5, 7.5, 8}
BasePetStatsArray[420] = {8.5, 7.5, 8}
BasePetStatsArray[421] = {8, 8.5, 7.5}
BasePetStatsArray[422] = {7.5, 8.5, 8}
BasePetStatsArray[423] = {8.5, 8.5, 7}
BasePetStatsArray[424] = {8.5, 7, 8.5}
BasePetStatsArray[425] = {7.5, 8, 8.5}
BasePetStatsArray[427] = {7, 8.5, 8.5}
BasePetStatsArray[428] = {7, 8.5, 8.5}
BasePetStatsArray[429] = {7.5, 8.5, 8}
BasePetStatsArray[430] = {8, 8.5, 7.5}
BasePetStatsArray[431] = {7.5, 8, 8.5}
BasePetStatsArray[432] = {8, 8, 8}
BasePetStatsArray[433] = {7.5, 8, 8.5}
BasePetStatsArray[434] = {8, 8, 8}
BasePetStatsArray[437] = {8, 8, 8}
BasePetStatsArray[438] = {7.5, 8, 8.5}
BasePetStatsArray[439] = {8.5, 8, 7.5}
BasePetStatsArray[440] = {8, 8, 8}
BasePetStatsArray[441] = {8, 7, 9}
BasePetStatsArray[442] = {9, 6.5, 8.5}
BasePetStatsArray[443] = {8, 8, 8}
BasePetStatsArray[444] = {8, 8, 8}
BasePetStatsArray[445] = {8, 8, 8}
BasePetStatsArray[446] = {8.5, 8, 7.5}
BasePetStatsArray[447] = {8, 7.5, 8.5}
BasePetStatsArray[448] = {8, 7, 9}
BasePetStatsArray[449] = {8, 8, 8}
BasePetStatsArray[450] = {9, 8, 7}
BasePetStatsArray[452] = {8, 8, 8}
BasePetStatsArray[453] = {9, 8, 7}
BasePetStatsArray[454] = {8, 7.5, 8.5}
BasePetStatsArray[455] = {8, 8, 8}
BasePetStatsArray[456] = {8, 8.5, 7.5}
BasePetStatsArray[457] = {9, 8, 7}
BasePetStatsArray[458] = {8.5, 8.5, 7}
BasePetStatsArray[459] = {7, 8.5, 8.5}
BasePetStatsArray[460] = {7.5, 8.5, 8}
BasePetStatsArray[461] = {9, 8, 7}
BasePetStatsArray[462] = {8, 8, 8}
BasePetStatsArray[463] = {9, 9, 6}
BasePetStatsArray[464] = {8, 8, 8}
BasePetStatsArray[465] = {7, 8.5, 8.5}
BasePetStatsArray[466] = {7.5, 8, 8.5}
BasePetStatsArray[467] = {7.5, 8.5, 8}
BasePetStatsArray[468] = {7.5, 8.5, 8}
BasePetStatsArray[469] = {7, 8.5, 8.5}
BasePetStatsArray[470] = {7, 8.5, 8.5}
BasePetStatsArray[471] = {8.5, 7.5, 8}
BasePetStatsArray[472] = {8.5, 7.5, 8}
BasePetStatsArray[473] = {9, 7.5, 7.5}
BasePetStatsArray[474] = {6, 8, 10}
BasePetStatsArray[475] = {8.5, 7, 8.5}
BasePetStatsArray[476] = {7.5, 7.5, 9}
BasePetStatsArray[477] = {7.5, 7.5, 9}
BasePetStatsArray[478] = {8.5, 8, 7.5}
BasePetStatsArray[479] = {8, 6.5, 9.5}
BasePetStatsArray[480] = {8, 8.5, 7.5}
BasePetStatsArray[482] = {7.5, 8, 8.5}
BasePetStatsArray[483] = {8.5, 7.5, 8}
BasePetStatsArray[484] = {7, 8.5, 8.5}
BasePetStatsArray[485] = {9, 7.5, 7.5}
BasePetStatsArray[486] = {8, 7.5, 8.5}
BasePetStatsArray[487] = {8, 8, 8}
BasePetStatsArray[488] = {7.5, 8, 8.5}
BasePetStatsArray[489] = {8, 8.5, 7.5}
BasePetStatsArray[491] = {7, 9, 8}
BasePetStatsArray[492] = {8, 8.5, 7.5}
BasePetStatsArray[493] = {9.5, 8.5, 6}
BasePetStatsArray[494] = {8, 8, 8}
BasePetStatsArray[495] = {8.5, 7.5, 8}
BasePetStatsArray[496] = {9.5, 8.5, 6}
BasePetStatsArray[497] = {8.5, 7, 8.5}
BasePetStatsArray[498] = {8.5, 8, 7.5}
BasePetStatsArray[499] = {8, 7.5, 8.5}
BasePetStatsArray[500] = {8, 8, 8}
BasePetStatsArray[502] = {8.5, 7.5, 8}
BasePetStatsArray[503] = {7.5, 7.5, 9}
BasePetStatsArray[504] = {8, 8.5, 7.5}
BasePetStatsArray[505] = {7.5, 8, 8.5}
BasePetStatsArray[506] = {7, 8.5, 8.5}
BasePetStatsArray[507] = {7.5, 8.5, 8}
BasePetStatsArray[508] = {8, 8, 8}
BasePetStatsArray[509] = {8, 8, 8}
BasePetStatsArray[510] = {8.5, 7.5, 8}
BasePetStatsArray[511] = {7.5, 8, 8.5}
BasePetStatsArray[512] = {7.5, 8.5, 8}
BasePetStatsArray[513] = {8, 8, 8}
BasePetStatsArray[514] = {8, 8, 8}
BasePetStatsArray[515] = {8, 8, 8}
BasePetStatsArray[517] = {8, 8, 8}
BasePetStatsArray[518] = {9, 8.5, 6.5}
BasePetStatsArray[519] = {8.5, 8, 7.5}
BasePetStatsArray[521] = {7, 9, 8}
BasePetStatsArray[523] = {9, 8, 7}
BasePetStatsArray[525] = {8, 8, 8}
BasePetStatsArray[528] = {7.5, 8, 8.5}
BasePetStatsArray[529] = {8, 8, 8}
BasePetStatsArray[530] = {8, 8, 8}
BasePetStatsArray[532] = {8.5, 9, 6.5}
BasePetStatsArray[534] = {7.5, 8.5, 8}
BasePetStatsArray[535] = {8, 8, 8}
BasePetStatsArray[536] = {8.5, 8, 7.5}
BasePetStatsArray[537] = {8.5, 8, 7.5}
BasePetStatsArray[538] = {8.5, 8.5, 7}
BasePetStatsArray[539] = {8, 7.5, 8.5}
BasePetStatsArray[540] = {8, 7.5, 8.5}
BasePetStatsArray[541] = {8.5, 7, 8.5}
BasePetStatsArray[542] = {8.5, 7.5, 8}
BasePetStatsArray[543] = {7.5, 8.5, 8}
BasePetStatsArray[544] = {8.5, 8.5, 7}
BasePetStatsArray[545] = {8, 8, 8}
BasePetStatsArray[546] = {7.5, 8.5, 8}
BasePetStatsArray[547] = {8, 7, 9}
BasePetStatsArray[548] = {7.5, 8.5, 8}
BasePetStatsArray[549] = {8, 8, 8}
BasePetStatsArray[550] = {8, 7.5, 8.5}
BasePetStatsArray[552] = {7.5, 8.5, 8}
BasePetStatsArray[553] = {8, 7.5, 8.5}
BasePetStatsArray[554] = {7.5, 8.5, 8}
BasePetStatsArray[555] = {8.5, 7, 8.5}
BasePetStatsArray[556] = {7.5, 8.5, 8}
BasePetStatsArray[557] = {7.5, 8.5, 8}
BasePetStatsArray[558] = {8, 8, 8}
BasePetStatsArray[559] = {7.5, 9, 7.5}
BasePetStatsArray[560] = {8.5, 7.5, 8}
BasePetStatsArray[562] = {7.5, 8, 8.5}
BasePetStatsArray[564] = {9.5, 7.5, 7}
BasePetStatsArray[565] = {8.5, 7.5, 8}
BasePetStatsArray[566] = {7.5, 7.5, 9}
BasePetStatsArray[567] = {7.5, 8, 8.5}
BasePetStatsArray[568] = {9.5, 8.5, 6}
BasePetStatsArray[569] = {8.5, 7.5, 8}
BasePetStatsArray[570] = {8, 8, 8}
BasePetStatsArray[571] = {7.5, 8, 8.5}
BasePetStatsArray[572] = {8.5, 8, 7.5}
BasePetStatsArray[573] = {9, 7, 8}
BasePetStatsArray[626] = {7.5, 8, 8.5}
BasePetStatsArray[627] = {8.5, 8.5, 7}
BasePetStatsArray[628] = {8.5, 8, 7.5}
BasePetStatsArray[629] = {8.5, 8, 7.5}
BasePetStatsArray[630] = {8, 8, 8}
BasePetStatsArray[631] = {7.5, 8, 8.5}
BasePetStatsArray[632] = {7.5, 8, 8.5}
BasePetStatsArray[633] = {8, 8, 8}
BasePetStatsArray[634] = {7, 8.5, 8.5}
BasePetStatsArray[635] = {7.5, 8, 8.5}
BasePetStatsArray[637] = {8, 8, 8}
BasePetStatsArray[638] = {8.5, 7, 8.5}
BasePetStatsArray[639] = {8, 7.5, 8.5}
BasePetStatsArray[640] = {8, 7, 9}
BasePetStatsArray[641] = {8, 7, 9}
BasePetStatsArray[644] = {8, 7.5, 8.5}
BasePetStatsArray[645] = {8, 8, 8}
BasePetStatsArray[646] = {8, 8, 8}
BasePetStatsArray[647] = {8, 8, 8}
BasePetStatsArray[648] = {9, 7.5, 7.5}
BasePetStatsArray[649] = {9, 7.5, 7.5}
BasePetStatsArray[650] = {8.5, 8, 7.5}
BasePetStatsArray[652] = {8, 8, 8}
BasePetStatsArray[665] = {7.5, 8.5, 8}
BasePetStatsArray[666] = {8, 8, 8}
BasePetStatsArray[671] = {8, 8, 8}
BasePetStatsArray[675] = {8, 7.5, 8.5}
BasePetStatsArray[677] = {8, 8, 8}
BasePetStatsArray[678] = {8, 8, 8}
BasePetStatsArray[679] = {8, 8, 8}
BasePetStatsArray[680] = {8, 8, 8}
BasePetStatsArray[699] = {7, 8.5, 8.5}
BasePetStatsArray[702] = {8.5, 7.5, 8}
BasePetStatsArray[703] = {8, 8, 8}
BasePetStatsArray[705] = {8, 8.5, 7.5}
BasePetStatsArray[706] = {8, 8, 8}
BasePetStatsArray[707] = {8, 8, 8}
BasePetStatsArray[708] = {8, 7.5, 8.5}
BasePetStatsArray[709] = {8, 7.5, 8.5}
BasePetStatsArray[710] = {8, 8, 8}
BasePetStatsArray[711] = {8, 8, 8}
BasePetStatsArray[712] = {8, 8, 8}
BasePetStatsArray[713] = {9, 7.5, 7.5}
BasePetStatsArray[714] = {7, 8.5, 8.5}
BasePetStatsArray[715] = {8, 8, 8}
BasePetStatsArray[716] = {7, 8.5, 8.5}
BasePetStatsArray[717] = {7.5, 8.5, 8}
BasePetStatsArray[718] = {8, 8, 8}
BasePetStatsArray[722] = {7.5, 8.5, 8}
BasePetStatsArray[723] = {9, 7.5, 7.5}
BasePetStatsArray[724] = {8, 8, 8}
BasePetStatsArray[725] = {8, 8, 8}
BasePetStatsArray[726] = {7, 8.5, 8.5}
BasePetStatsArray[727] = {8, 8, 8}
BasePetStatsArray[728] = {8, 8, 8}
BasePetStatsArray[729] = {8, 7, 9}
BasePetStatsArray[730] = {8, 7, 9}
BasePetStatsArray[731] = {7, 8.5, 8.5}
BasePetStatsArray[732] = {8, 8.5, 7.5}
BasePetStatsArray[733] = {8, 8, 8}
BasePetStatsArray[737] = {6.5, 8, 9.5}
BasePetStatsArray[739] = {7, 8, 9}
BasePetStatsArray[740] = {8, 7.5, 8.5}
BasePetStatsArray[741] = {8, 8, 8}
BasePetStatsArray[742] = {8, 8, 8}
BasePetStatsArray[743] = {9.5, 8.5, 6}
BasePetStatsArray[744] = {8.5, 7, 8.5}
BasePetStatsArray[745] = {8, 8, 8}
BasePetStatsArray[746] = {8.5, 9, 6.5}
BasePetStatsArray[747] = {7.5, 8.5, 8}
BasePetStatsArray[748] = {8, 8.5, 7.5}
BasePetStatsArray[749] = {8, 8, 8}
BasePetStatsArray[750] = {8, 8, 8}
BasePetStatsArray[751] = {8, 7.5, 8.5}
BasePetStatsArray[752] = {9, 7.5, 7.5}
BasePetStatsArray[753] = {7.5, 8.5, 8}
BasePetStatsArray[754] = {8, 8, 8}
BasePetStatsArray[755] = {9, 6.5, 8.5}
BasePetStatsArray[756] = {8.5, 7, 8.5}
BasePetStatsArray[757] = {8.5, 8, 7.5}
BasePetStatsArray[758] = {7.5, 8.5, 8}
BasePetStatsArray[792] = {8, 8.5, 7.5}
BasePetStatsArray[800] = {8, 8, 8}
BasePetStatsArray[802] = {8.5, 8.5, 7}
BasePetStatsArray[817] = {8.5, 8, 7.5}
BasePetStatsArray[818] = {8, 8.5, 7.5}
BasePetStatsArray[819] = {7.5, 8.5, 8}
BasePetStatsArray[820] = {8, 8, 8}
BasePetStatsArray[821] = {8, 8, 8}
BasePetStatsArray[823] = {8, 8, 8}
BasePetStatsArray[824] = {8, 8, 8}
BasePetStatsArray[825] = {8, 8, 8}
BasePetStatsArray[826] = {8, 8, 8}
BasePetStatsArray[827] = {8, 8, 8}
BasePetStatsArray[828] = {8, 8, 8}
BasePetStatsArray[829] = {8, 8, 8}
BasePetStatsArray[830] = {8, 8, 8}
BasePetStatsArray[831] = {8, 8, 8}
BasePetStatsArray[832] = {8, 8, 8}
BasePetStatsArray[833] = {8, 8, 8}
BasePetStatsArray[834] = {8.5, 8, 7.5}
BasePetStatsArray[835] = {8, 8, 8}
BasePetStatsArray[836] = {7.5, 7, 9.5}
BasePetStatsArray[837] = {8.5, 8, 7.5}
BasePetStatsArray[838] = {8, 8, 8}
BasePetStatsArray[844] = {8, 8.5, 7.5}
BasePetStatsArray[845] = {8, 8, 8}
BasePetStatsArray[846] = {6, 8, 10}
BasePetStatsArray[847] = {8, 8, 8}
BasePetStatsArray[848] = {8, 7, 9}
BasePetStatsArray[849] = {8, 8, 8}
BasePetStatsArray[850] = {8, 8, 8}
BasePetStatsArray[851] = {7.5, 8, 8.5}
BasePetStatsArray[855] = {7.5, 8.5, 8}
BasePetStatsArray[856] = {8, 8, 8}
BasePetStatsArray[868] = {8, 8, 8}
BasePetStatsArray[872] = {8, 8, 8}
BasePetStatsArray[873] = {8, 8, 8}
BasePetStatsArray[874] = {8, 8, 8}
BasePetStatsArray[875] = {8, 8, 8}
BasePetStatsArray[876] = {8, 8, 8}
BasePetStatsArray[877] = {8, 8, 8}
BasePetStatsArray[878] = {8, 8, 8}
BasePetStatsArray[879] = {8, 8, 8}
BasePetStatsArray[880] = {8, 8, 8}
BasePetStatsArray[881] = {8, 8, 8}
BasePetStatsArray[882] = {8, 8, 8}
BasePetStatsArray[883] = {8, 8, 8}
BasePetStatsArray[884] = {8, 8, 8}
BasePetStatsArray[885] = {8, 8, 8}
BasePetStatsArray[886] = {8, 8, 8}
BasePetStatsArray[887] = {8, 8, 8}
BasePetStatsArray[888] = {8, 8, 8}
BasePetStatsArray[889] = {8, 8, 8}
BasePetStatsArray[890] = {8, 8, 8}
BasePetStatsArray[891] = {8, 8, 8}
BasePetStatsArray[892] = {8, 8, 8}
BasePetStatsArray[893] = {8, 8, 8}
BasePetStatsArray[894] = {8, 8, 8}
BasePetStatsArray[895] = {8, 8, 8}
BasePetStatsArray[896] = {8, 8, 8}
BasePetStatsArray[897] = {8, 8, 8}
BasePetStatsArray[898] = {8, 8, 8}
BasePetStatsArray[899] = {8, 8, 8}
BasePetStatsArray[900] = {8, 8, 8}
BasePetStatsArray[901] = {8, 8, 8}
BasePetStatsArray[902] = {8, 8, 8}
BasePetStatsArray[903] = {7.5, 9, 7.5}
BasePetStatsArray[904] = {8, 8, 8}
BasePetStatsArray[905] = {8, 8, 8}
BasePetStatsArray[906] = {8, 8, 8}
BasePetStatsArray[907] = {8, 8, 8}
BasePetStatsArray[908] = {8, 8, 8}
BasePetStatsArray[909] = {8, 8, 8}
BasePetStatsArray[911] = {8, 8.5, 7.5}
BasePetStatsArray[912] = {8, 8.5, 7.5}
BasePetStatsArray[913] = {8, 8.5, 7.5}
BasePetStatsArray[915] = {8, 8, 8}
BasePetStatsArray[916] = {8, 8, 8}
BasePetStatsArray[917] = {8, 8, 8}
BasePetStatsArray[921] = {8, 8, 8}
BasePetStatsArray[922] = {8, 8, 8}
BasePetStatsArray[923] = {8.5, 7.5, 8}
BasePetStatsArray[924] = {8, 8, 8}
BasePetStatsArray[925] = {8, 8, 8}
BasePetStatsArray[926] = {8, 8, 8}
BasePetStatsArray[927] = {8, 8, 8}
BasePetStatsArray[928] = {8, 8, 8}
BasePetStatsArray[929] = {8, 8, 8}
BasePetStatsArray[931] = {8, 8, 8}
BasePetStatsArray[932] = {8, 8, 8}
BasePetStatsArray[933] = {8, 8, 8}
BasePetStatsArray[934] = {8, 8, 8}
BasePetStatsArray[935] = {8, 8, 8}
BasePetStatsArray[936] = {8, 8, 8}
BasePetStatsArray[937] = {8, 8, 8}
BasePetStatsArray[938] = {8, 8, 8}
BasePetStatsArray[939] = {8, 8, 8}
BasePetStatsArray[941] = {8, 8, 8}
BasePetStatsArray[942] = {8, 8, 8}
BasePetStatsArray[943] = {8, 8, 8}
BasePetStatsArray[944] = {8, 8, 8}
BasePetStatsArray[945] = {8, 8, 8}
BasePetStatsArray[946] = {8, 8, 8}
BasePetStatsArray[947] = {8, 8, 8}
BasePetStatsArray[948] = {8, 8, 8}
BasePetStatsArray[949] = {8, 8, 8}
BasePetStatsArray[950] = {8, 8, 8}
BasePetStatsArray[951] = {8, 8, 8}
BasePetStatsArray[952] = {8, 8, 8}
BasePetStatsArray[953] = {8, 8, 8}
BasePetStatsArray[954] = {8, 8, 8}
BasePetStatsArray[955] = {8, 8, 8}
BasePetStatsArray[956] = {8, 8, 8}
BasePetStatsArray[957] = {8, 8, 8}
BasePetStatsArray[958] = {8, 8, 8}
BasePetStatsArray[959] = {8, 8, 8}
BasePetStatsArray[960] = {8, 8, 8}
BasePetStatsArray[961] = {8, 8, 8}
BasePetStatsArray[962] = {8, 8, 8}
BasePetStatsArray[963] = {8, 8, 8}
BasePetStatsArray[964] = {8, 8, 8}
BasePetStatsArray[965] = {8, 8, 8}
BasePetStatsArray[966] = {8, 8, 8}
BasePetStatsArray[967] = {8, 8, 8}
BasePetStatsArray[968] = {8, 8, 8}
BasePetStatsArray[969] = {8, 8, 8}
BasePetStatsArray[970] = {8, 8, 8}
BasePetStatsArray[971] = {8, 8, 8}
BasePetStatsArray[972] = {8, 8, 8}
BasePetStatsArray[973] = {8, 8, 8}
BasePetStatsArray[974] = {8, 8, 8}
BasePetStatsArray[975] = {8, 8, 8}
BasePetStatsArray[976] = {8, 8, 8}
BasePetStatsArray[977] = {8.5, 8.5, 8.5}
BasePetStatsArray[978] = {8.5, 8.5, 8.5}
BasePetStatsArray[979] = {8.5, 8.5, 8.5}
BasePetStatsArray[980] = {8.5, 8.5, 8.5}
BasePetStatsArray[981] = {8.5, 8.5, 8.5}
BasePetStatsArray[982] = {8.5, 8.5, 8.5}
BasePetStatsArray[983] = {8.5, 8.5, 8.5}
BasePetStatsArray[984] = {8.5, 8.5, 8.5}
BasePetStatsArray[985] = {8.5, 8.5, 8.5}
BasePetStatsArray[986] = {8.5, 8.5, 8.5}
BasePetStatsArray[987] = {8.5, 8.5, 8.5}
BasePetStatsArray[988] = {8.5, 8.5, 8.5}
BasePetStatsArray[989] = {8, 8, 8}
BasePetStatsArray[990] = {8, 8, 8}
BasePetStatsArray[991] = {8, 8, 8}
BasePetStatsArray[992] = {8, 8, 8}
BasePetStatsArray[993] = {8, 8, 8}
BasePetStatsArray[994] = {8, 8, 8}
BasePetStatsArray[995] = {8, 8, 8}
BasePetStatsArray[996] = {8, 8, 8}
BasePetStatsArray[997] = {8, 8, 8}
BasePetStatsArray[998] = {8, 8, 8}
BasePetStatsArray[999] = {8, 8, 8}
BasePetStatsArray[1000] = {8, 8, 8}
BasePetStatsArray[1001] = {8, 8, 8}
BasePetStatsArray[1002] = {9, 9, 9}
BasePetStatsArray[1003] = {9, 9, 9}
BasePetStatsArray[1004] = {8, 8, 8}
BasePetStatsArray[1005] = {8, 8, 8}
BasePetStatsArray[1006] = {8, 8, 8}
BasePetStatsArray[1007] = {8, 8, 8}
BasePetStatsArray[1008] = {8, 8, 8}
BasePetStatsArray[1009] = {8, 8, 8}
BasePetStatsArray[1010] = {8, 8, 8}
BasePetStatsArray[1011] = {8, 8, 8}
BasePetStatsArray[1012] = {8, 8, 8}
BasePetStatsArray[1013] = {9, 7.5, 7.5}
BasePetStatsArray[1039] = {7.5, 7.5, 9}
BasePetStatsArray[1040] = {8, 8, 8}
BasePetStatsArray[1042] = {6.75, 10.5, 6.75}
BasePetStatsArray[1061] = {8, 8, 8}
BasePetStatsArray[1062] = {8, 7.5, 8.5}
BasePetStatsArray[1063] = {8.5, 8.5, 7}
BasePetStatsArray[1065] = {8.5, 8.5, 7}
BasePetStatsArray[1066] = {8, 8, 8}
BasePetStatsArray[1067] = {8.5, 7.5, 8}
BasePetStatsArray[1068] = {8, 8, 8}
BasePetStatsArray[1073] = {8, 8, 8}
BasePetStatsArray[1117] = {7, 8.5, 8.5}
BasePetStatsArray[1124] = {8, 8, 8}
BasePetStatsArray[1125] = {8, 8, 8}
BasePetStatsArray[1126] = {8, 8, 8}
BasePetStatsArray[1127] = {7.5, 8.5, 8}
BasePetStatsArray[1128] = {8, 8, 8}
BasePetStatsArray[1129] = {8, 8, 8}
BasePetStatsArray[1130] = {8, 8, 8}
BasePetStatsArray[1131] = {8, 8, 8}
BasePetStatsArray[1132] = {8, 8, 8}
BasePetStatsArray[1133] = {8, 8, 8}
BasePetStatsArray[1134] = {8, 8, 8}
BasePetStatsArray[1135] = {8, 8, 8}
BasePetStatsArray[1136] = {8, 8, 8}
BasePetStatsArray[1137] = {8, 8, 8}
BasePetStatsArray[1138] = {8, 8, 8}
BasePetStatsArray[1139] = {8, 8, 8}
BasePetStatsArray[1140] = {8, 8, 8}
BasePetStatsArray[1141] = {8, 8, 8}
BasePetStatsArray[1142] = {8.5, 7.5, 8}
BasePetStatsArray[1143] = {8, 8, 8}
BasePetStatsArray[1144] = {8, 8, 8}
BasePetStatsArray[1145] = {8, 8, 8}
BasePetStatsArray[1146] = {8, 8, 8}
BasePetStatsArray[1147] = {8, 8, 8}
BasePetStatsArray[1149] = {8, 8, 8}
BasePetStatsArray[1150] = {8, 8, 8}
BasePetStatsArray[1151] = {8, 8, 8}
BasePetStatsArray[1152] = {7.5, 8.5, 8}
BasePetStatsArray[1153] = {8, 8, 8}
BasePetStatsArray[1154] = {8, 8, 8}
BasePetStatsArray[1155] = {8, 8.5, 7.5}
BasePetStatsArray[1156] = {8, 8, 8}
BasePetStatsArray[1157] = {8, 8, 8}
BasePetStatsArray[1158] = {8, 8, 8}
BasePetStatsArray[1159] = {7.5, 8.5, 8}
BasePetStatsArray[1160] = {8.5, 8, 7.5}
BasePetStatsArray[1161] = {8, 8.5, 7.5}
BasePetStatsArray[1162] = {7, 9, 8}
BasePetStatsArray[1163] = {9, 8, 7}
BasePetStatsArray[1164] = {7.5, 8, 8.5}
BasePetStatsArray[1165] = {8, 8.5, 7.5}
BasePetStatsArray[1166] = {8, 8.5, 7.5}
BasePetStatsArray[1167] = {8, 8.5, 7.5}
BasePetStatsArray[1168] = {8, 8, 8}